@@ -1,34 +1,37 @@
-// -*- Mode: C++; indent-tabs-mode: nil; c-basic-offset: 4; -*-
+// -*- mode: c++; indent-tabs-mode: nil; c-basic-offset: 4; fill-column: 78 -*-
 //
 // OpenVRML
 //
-// Copyright (C) 2000  Christopher K. St. John
+// Copyright 2000  Christopher K. St. John
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation; either
-// version 2.1 of the License, or (at your option) any later version.
+// This library is free software; you can redistribute it and/or modify it
+// under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or (at your
+// option) any later version.
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Lesser General Public License for more details.
+// This library is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+// License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// You should have received a copy of the GNU Lesser General Public License
+// along with this library; if not, see <http://www.gnu.org/licenses/>.
 //
 
 # include <limits>
-# include "private.h"
+# include <openvrml/local/float.h>
 # include "bounding_volume.h"
 # include "field_value.h"
 # include "frustum.h"
 
-namespace openvrml {
+/**
+ * @file openvrml/bounding_volume.h
+ *
+ * @brief Bounding volumes.
+ */
 
 /**
- * @class bounding_volume
+ * @class openvrml::bounding_volume openvrml/bounding_volume.h
  *
  * @brief A bounding volume.
  *
@@ -38,40 +41,63 @@ namespace openvrml {
  * that are expected to be static. That probably means boxes for geometry and
  * spheres for grouping nodes.
  *
- * @see node::render
- * @see bounding_sphere
- * @see axis_aligned_bounding_box
+ * @see openvrml::bounding_sphere
+ * @see openvrml::axis_aligned_bounding_box
  */
 
 /**
- * @var bounding_volume::inside
+ * @enum openvrml::bounding_volume::intersection
  *
- * @brief Results of an intersection; indicates that the tested volume is
- *      entirely inside the target volume.
+ * @brief Indicates the type of intersection.
  */
 
 /**
- * @var bounding_volume::outside
+ * @var openvrml::bounding_volume::intersection openvrml::bounding_volume::outside
  *
- * @brief Results of an intersection; indicates that the tested volume is
- *      entirely outside the target volume.
+ * @brief Indicates that the tested volume is entirely outside the target
+ *        volume.
  */
 
 /**
- * @var bounding_volume::partial
+ * @var openvrml::bounding_volume::intersection openvrml::bounding_volume::partial
  *
- * @brief Results of an intersection; indicates that the tested volume
- *      intersects with the target volume.
+ * @brief Indicates that the tested volume intersects with the target volume.
  */
 
 /**
- * @brief Destructor.
- */
-bounding_volume::~bounding_volume() {}
-
-/**
- * @fn bool bounding_volume::maximized() const
+ * @var openvrml::bounding_volume::intersection openvrml::bounding_volume::inside
  *
+ * @brief Indicates that the tested volume is entirely inside the target
+ *        volume.
+ */
+
+/**
+ * @brief Destroy.
+ */
+openvrml::bounding_volume::~bounding_volume() OPENVRML_NOTHROW
+{}
+
+/**
+ * @brief Maximize the bounding volume.
+ *
+ * Delegates to <code>bounding_volume::do_maximize</code>.
+ *
+ * @see maximized
+ */
+void openvrml::bounding_volume::maximize()
+{
+    this->do_maximize();
+}
+
+/**
+ * @fn void openvrml::bounding_volume::do_maximize()
+ *
+ * @brief Called by <code>bounding_volume::maximize</code>.
+ *
+ * @see maximize
+ */
+
+/**
  * @brief Indicates whether the bounding volume is maximized.
  *
  * The convention is that nodes that should be rendered unconditionally set a
@@ -82,21 +108,26 @@ bounding_volume::~bounding_volume() {}
  *
  * @return @c true if the bounding voume is maximized; @c false otherwise.
  *
- * @see maximize
+ * @see openvrml::bounding_volume::maximize
+ */
+bool openvrml::bounding_volume::maximized() const OPENVRML_NOTHROW
+{
+    return this->do_maximized();
+}
+
+/**
+ * @fn bool openvrml::bounding_volume::do_maximized() const
+ *
+ * @brief Called by <code>bounding_volume::maximized</code>.
+ *
+ * @return @c true if the bounding voume is maximized; @c false otherwise.
+ *
+ * @see openvrml::bounding_volume::maximized
  */
 
 /**
- * @fn void bounding_volume::maximize()
- *
- * @brief Maximize the bounding volume.
- *
- * @see maximized
- */
-
-/**
- * @fn bounding_volume::intersection bounding_volume::intersect_frustum(const openvrml::frustum & frustum) const
- *
- * @brief Intersect this bvolume with a frustum.
+ * @brief Intersect this <code>bounding_volume</code> with a
+ *        <code>frustum</code>.
  *
  * The test assumes that the frustum is in the canonical
  * looking-down-negative-z orientation, so the bounding volume is going to have
@@ -105,59 +136,117 @@ bounding_volume::~bounding_volume() {}
  * them into the projection space. Lots of tradeoffs involved, but transforming
  * the bvolume is probably the simplest approach overall.)
  *
- * @param frustum   the frustum.
+ * @param[in] frustum   the frustum.
  *
  * @return inside, outside, or partial.
  *
- * @see bounding_volume::transform
- * @see bounding_volume::ortho_transform
+ * @see openvrml::bounding_volume::transform
+ * @see openvrml::bounding_volume::ortho_transform
+ */
+openvrml::bounding_volume::intersection
+openvrml::bounding_volume::
+intersect_frustum(const openvrml::frustum & frustum) const
+{
+    return this->do_intersect_frustum(frustum);
+}
+
+/**
+ * @fn openvrml::bounding_volume::intersection openvrml::bounding_volume::do_intersect_frustum(const openvrml::frustum & frustum) const
+ *
+ * @brief Called by <code>bounding_volume::intersect_frustum</code>
+ *
+ * @param[in] frustum   the frustum.
+ *
+ * @return inside, outside, or partial.
+ *
+ * @see openvrml::bounding_volume::transform
+ * @see openvrml::bounding_volume::ortho_transform
  */
 
 /**
- * @fn void bounding_volume::extend(const bounding_volume & bv)
- *
  * @brief Extend the bounding_volume to enclose @p bv.
  *
- * @param bv    a bounding volume.
+ * Delegates to
+ * <code>bounding_volume::do_extend(const bounding_sphere &)</code> and
+ * <code>bounding_volume::do_extend(const axis_alligned_bounding_box &)</code>.
+ *
+ * @param[in] bv    a bounding volume.
  */
+void openvrml::bounding_volume::extend(const bounding_volume & bv)
+{
+    // doing two tests isn't a big deal, if there get to be too many
+    // more kinds of bounding volumes, move to a double dispatch
+    // pattern.
+    const bounding_sphere * bs = 0;
+    const axis_aligned_bounding_box * ab = 0;
+    if ((bs = dynamic_cast<const bounding_sphere *>(&bv))) {
+        this->do_extend(*bs);
+    } else if ((ab = dynamic_cast<const axis_aligned_bounding_box *>(&bv))) {
+        this->do_extend(*ab);
+    }
+}
 
 /**
- * @fn void bounding_volume::extend(const vec3f & p)
+ * @brief Extend the bounding volume to enclose @p p.
+ *
+ * Delegates to <code>bounding_volume::do_extend</code>.
+ *
+ * @param[in] p a point
+ */
+void openvrml::bounding_volume::extend(const vec3f & p)
+{
+    this->do_extend(p);
+}
+
+/**
+ * @fn void openvrml::bounding_volume::do_extend(const vec3f & p)
  *
  * @brief Extend the bounding volume to enclose @p p.
  *
- * @param p a point
+ * @param[in] p a point
  */
 
 /**
- * @fn void bounding_volume::extend(const axis_aligned_bounding_box & bbox)
+ * @fn void openvrml::bounding_volume::do_extend(const axis_aligned_bounding_box & bbox)
  *
- * @brief Extend the bounding volume to enclose @p bbox.
+ * @brief Called by
+ *        <code>bounding_volume::extend(const bounding_volume &)</code>.
  *
- * @param bbox  an axis-aligned bounding box.
+ * @param[in] bbox  an axis-aligned bounding box.
  */
 
 /**
- * @fn void bounding_volume::extend(const bounding_sphere & b)
+ * @fn void openvrml::bounding_volume::do_extend(const bounding_sphere & b)
  *
- * @brief Extend this bvolume to enclose the given sphere.
+ * @brief Called by
+ *        <code>bounding_volume::extend(const bounding_volume &)</code>.
  *
- * @param b a bounding sphere
+ * @param[in] b a bounding sphere
  */
 
 /**
- * @fn void bounding_volume::enclose(const std::vector<vec3f> & points)
- *
  * @brief Enclose the given set of points.
  *
  * This resets the volume from any previous values.
  *
- * @param points    points.
+ * Delegates to <code>bounding_volume::do_enclose</code>.
+ *
+ * @param[in] points    points.
+ */
+void openvrml::bounding_volume::enclose(const std::vector<vec3f> & points)
+{
+    this->do_enclose(points);
+}
+
+/**
+ * @fn void openvrml::bounding_volume::do_enclose(const std::vector<vec3f> & points)
+ *
+ * @brief Called by <code>bounding_volume::enclose</code>.
+ *
+ * @param[in] points    points.
  */
 
 /**
- * @fn void bounding_volume::ortho_transform(const mat4f & M)
- *
  * @brief Transform this bounding volume using an orthogonal transfom.
  *
  * Orthogonal transformations preserve angles. They include
@@ -168,14 +257,24 @@ bounding_volume::~bounding_volume() {}
  * orthogonal, otherwise the results are undefined. If in doubt,
  * call transform instead and take the speed hit.
  *
- * @param M orthonormal transformation matrix in mat4f format
+ * Delegates to <code>bounding_volume::do_ortho_transform</code>.
  *
- * @see MathUtils
+ * @param[in] M orthonormal transformation matrix.
+ */
+void openvrml::bounding_volume::ortho_transform(const mat4f & M)
+{
+    this->do_ortho_transform(M);
+}
+
+/**
+ * @fn void openvrml::bounding_volume::do_ortho_transform(const mat4f & M)
+ *
+ * @brief Called by <code>bounding_volume::ortho_transform</code>.
+ *
+ * @param[in] M orthonormal transformation matrix in mat4f format
  */
 
 /**
- * @fn void bounding_volume::transform(const mat4f & M)
- *
  * @brief Transform this bounding volume using an affine transfom.
  *
  * Affine transformations can include nonuniform scaling. It is much
@@ -188,12 +287,26 @@ bounding_volume::~bounding_volume() {}
  * affine transformations, so unless you're doing something tricky
  * this routine should always be safe.
  *
- * @param M affine transformation matrix.
+ * Delegates to <code>bounding_volume::do_transform</code>.
+ *
+ * @param[in] M affine transformation matrix.
+ */
+void openvrml::bounding_volume::transform(const mat4f & M)
+{
+    this->do_transform(M);
+}
+
+/**
+ * @fn void openvrml::bounding_volume::do_transform(const mat4f & M)
+ *
+ * @brief Called by <code>bounding_volume::transform</code>.
+ *
+ * @param[in] M affine transformation matrix.
  */
 
 
 /**
- * @class bounding_sphere
+ * @class openvrml::bounding_sphere
  *
  * @brief A bounding sphere.
  *
@@ -204,13 +317,13 @@ bounding_volume::~bounding_volume() {}
  */
 
 /**
- * @var bounding_sphere::center_
+ * @var openvrml::bounding_sphere::center_
  *
  * @brief The center of the sphere.
  */
 
 /**
- * @var bounding_sphere::radius_
+ * @var openvrml::bounding_sphere::radius_
  *
  * @brief The radius of the sphere.
  */
@@ -218,25 +331,26 @@ bounding_volume::~bounding_volume() {}
 /**
  * @brief Construct.
  */
-bounding_sphere::bounding_sphere():
+openvrml::bounding_sphere::bounding_sphere():
+    center_(make_vec3f()),
     radius_(-1.0)
 {}
 
 /**
  * @brief Destroy.
  */
-bounding_sphere::~bounding_sphere()
+openvrml::bounding_sphere::~bounding_sphere() OPENVRML_NOTHROW
 {}
 
 namespace {
-    float sphere_plane_distance(const bounding_sphere & bs,
+    float sphere_plane_distance(const openvrml::bounding_sphere & bs,
                                 const float N[3],
                                 float D)
     {
         //
         // r = Ax + By + Cz + D
         //
-        const vec3f & c = bs.center();
+        const openvrml::vec3f & c = bs.center();
         float d = N[0] * c[0] + N[1] * c[1] + N[2] * c[2] - D;
         return d;
     }
@@ -252,15 +366,16 @@ namespace {
  * both of them into the projection space. Lots of tradeoffs involved, but
  * transforming the bounding volume is probably the simplest approach overall.)
  *
- * @param frustum   the frustum.
+ * @param[in] frustum   the frustum.
  *
  * @return inside, outside, or partial.
  *
  * @see bounding_volume::transform
  * @see bounding_volume::ortho_transform
  */
-bounding_volume::intersection
-bounding_sphere::intersect_frustum(const openvrml::frustum & frustum) const
+openvrml::bounding_volume::intersection
+openvrml::bounding_sphere::
+do_intersect_frustum(const openvrml::frustum & frustum) const
 {
     if (this->maximized()) { return bounding_volume::partial; }
     if (this->radius_ == -1.0f) { return bounding_volume::partial; } // ???
@@ -304,44 +419,29 @@ bounding_sphere::intersect_frustum(const openvrml::frustum & frustum) const
     if (d < -this->radius_) { return bounding_volume::outside; }
     if (d < this->radius_) { code = bounding_volume::partial; }
 
-    d = sphere_plane_distance(*this, frustum.left_plane, frustum.left_plane[3]);
+    d = sphere_plane_distance(*this,
+                              frustum.left_plane,
+                              frustum.left_plane[3]);
     if (d < -this->radius_) { return bounding_volume::outside; }
     if (d < this->radius_) { code = bounding_volume::partial; }
 
-    d = sphere_plane_distance(*this, frustum.right_plane, frustum.right_plane[3]);
+    d = sphere_plane_distance(*this,
+                              frustum.right_plane,
+                              frustum.right_plane[3]);
     if (d < -this->radius_) { return bounding_volume::outside; }
     if (d < this->radius_) { code = bounding_volume::partial; }
 
     return code;
 }
 
-/**
- * @brief Extend the bounding_volume to enclose @p bv.
- *
- * @param bv    a bounding volume.
- */
-void bounding_sphere::extend(const bounding_volume & bv)
-{
-    // doing two tests isn't a big deal, if there get to be too many
-    // more kinds of bounding volumes, move to a double dispatch
-    // pattern.
-    const bounding_sphere * bs = 0;
-    const axis_aligned_bounding_box * ab = 0;
-    if ((bs = dynamic_cast<const bounding_sphere *>(&bv))) {
-        this->extend(*bs);
-    } else if ((ab = dynamic_cast<const axis_aligned_bounding_box *>(&bv))) {
-        this->extend(*ab);
-    }
-}
-
 /**
  * @brief Extend to enclose @p p.
  *
- * @param p a point.
+ * @param[in] p a point.
  */
-void bounding_sphere::extend(const vec3f & p)
+void openvrml::bounding_sphere::do_extend(const vec3f & p)
 {
-    using openvrml_::fequal;
+    using openvrml::local::fequal;
 
     if (this->maximized()) { return; }
 
@@ -372,7 +472,7 @@ void bounding_sphere::extend(const vec3f & p)
     float zn = z1 - z0;
     float dn = float(sqrt(xn * xn + yn * yn + zn * zn));
 
-    if (fequal<float>()(dn, 0.0f)) { return; }
+    if (fequal(dn, 0.0f)) { return; }
 
     if (dn < r0) {
         // point is inside sphere
@@ -396,19 +496,20 @@ void bounding_sphere::extend(const vec3f & p)
  *
  * @todo Implement me!
  *
- * @param bbox  an axis-aligned bounding box
+ * @param[in] bbox  an axis-aligned bounding box
  */
-void bounding_sphere::extend(const axis_aligned_bounding_box & bbox)
+void
+openvrml::bounding_sphere::do_extend(const axis_aligned_bounding_box &)
 {}
 
 /**
  * @brief Extend this bvolume to enclose the given sphere.
  *
- * @param b a bounding sphere
+ * @param[in] b a bounding sphere
  */
-void bounding_sphere::extend(const bounding_sphere & b)
+void openvrml::bounding_sphere::do_extend(const bounding_sphere & b)
 {
-    using openvrml_::fequal;
+    using openvrml::local::fequal;
 
     if (this->maximized()) { return; }
 
@@ -447,7 +548,7 @@ void bounding_sphere::extend(const bounding_sphere & b)
     float zn = z1 - z0;
     float dn = float(sqrt(xn * xn + yn * yn + zn * zn));
 
-    if (fequal<float>()(dn, 0.0f)) { return; }
+    if (fequal(dn, 0.0f)) { return; }
 
     if (dn + r1 < r0) { // inside us, so no change
         return;
@@ -464,7 +565,7 @@ void bounding_sphere::extend(const bounding_sphere & b)
     float cz = z0 + zn * tmp;
 
     this->radius_ = cr;
-    this->center_ = vec3f(cx, cy, cz);
+    this->center_ = make_vec3f(cx, cy, cz);
 }
 
 /**
@@ -472,9 +573,9 @@ void bounding_sphere::extend(const bounding_sphere & b)
  *
  * This resets the volume from any previous values.
  *
- * @param points    points.
+ * @param[in] points    points.
  */
-void bounding_sphere::enclose(const std::vector<vec3f> & points)
+void openvrml::bounding_sphere::do_enclose(const std::vector<vec3f> & points)
 {
     // doing an extend() for each point is ok, but there are
     // faster algorithms reference "An Efficient Bounding Sphere"
@@ -510,8 +611,7 @@ void bounding_sphere::enclose(const std::vector<vec3f> & points)
     //
     // Pick the two points most distant from one another.
     //
-    vec3f span;
-    span = *max_p[0] - *min_p[0];
+    vec3f span = *max_p[0] - *min_p[0];
     float dx = span.dot(span);
     span = *max_p[1] - *min_p[1];
     float dy = span.dot(span);
@@ -544,7 +644,7 @@ void bounding_sphere::enclose(const std::vector<vec3f> & points)
  *
  * @return the center coordinates.
  */
-const vec3f & bounding_sphere::center() const
+const openvrml::vec3f & openvrml::bounding_sphere::center() const
 {
     return this->center_;
 }
@@ -552,9 +652,9 @@ const vec3f & bounding_sphere::center() const
 /**
  * @brief Set the center coordinates.
  *
- * @param c new center coordinates.
+ * @param[in] c new center coordinates.
  */
-void bounding_sphere::center(const vec3f & c)
+void openvrml::bounding_sphere::center(const vec3f & c)
 {
     this->center_ = c;
 }
@@ -564,7 +664,7 @@ void bounding_sphere::center(const vec3f & c)
  *
  * @return the radius.
  */
-float bounding_sphere::radius() const
+float openvrml::bounding_sphere::radius() const
 {
     return this->radius_;
 }
@@ -572,9 +672,9 @@ float bounding_sphere::radius() const
 /**
  * @brief Set the radius.
  *
- * @param r new radius value.
+ * @param[in] r new radius value.
  */
-void bounding_sphere::radius(const float r)
+void openvrml::bounding_sphere::radius(const float r)
 {
     this->radius_ = r;
 }
@@ -582,10 +682,10 @@ void bounding_sphere::radius(const float r)
 /**
  * @brief Extend the bounding sphere to infinity.
  */
-void bounding_sphere::maximize()
+void openvrml::bounding_sphere::do_maximize()
 {
     this->radius_ = std::numeric_limits<float>::max();
-    this->center_ = vec3f(0.0, 0.0, 0.0);
+    this->center_ = make_vec3f(0.0, 0.0, 0.0);
 }
 
 /**
@@ -594,7 +694,7 @@ void bounding_sphere::maximize()
  * @return @c true if the bounding_sphere has been maximized; @c false
  *         otherwise.
  */
-bool bounding_sphere::maximized() const
+bool openvrml::bounding_sphere::do_maximized() const
 {
     if (this->radius_ == std::numeric_limits<float>::max()) { return true; }
     return false;
@@ -603,9 +703,9 @@ bool bounding_sphere::maximized() const
 /**
  * @brief Orthographically transform the bounding_sphere by @p t.
  *
- * @param t transformation matrix.
+ * @param[in] t transformation matrix.
  */
-void bounding_sphere::ortho_transform(const mat4f & t)
+void openvrml::bounding_sphere::do_ortho_transform(const mat4f & t)
 {
     if (this->maximized()) { return; }
     if (this->radius_ == -1) { return; }
@@ -615,23 +715,23 @@ void bounding_sphere::ortho_transform(const mat4f & t)
 
     // uniform scale means we can pick any of the scale elements? wait:
     // can we really do this?
-    this->radius_ *= vec3f(t[0][0], t[1][0], t[2][0]).length();
+    this->radius_ *= make_vec3f(t[0][0], t[1][0], t[2][0]).length();
 }
 
 /**
  * @brief Transform the bounding_sphere by @p t.
  *
- * @param t transformation matrix.
+ * @param[in] t transformation matrix.
  */
-void bounding_sphere::transform(const mat4f & t)
+void openvrml::bounding_sphere::do_transform(const mat4f & t)
 {
     if (this->maximized()) { return; }
     if (this->radius_ == -1) { return; }
     this->center_ *= t;
 
-    vec3f x_scale_v(t[0][0], t[1][0], t[2][0]);
-    vec3f y_scale_v(t[0][1], t[1][1], t[2][1]);
-    vec3f z_scale_v(t[0][2], t[1][2], t[2][2]);
+    vec3f x_scale_v = make_vec3f(t[0][0], t[1][0], t[2][0]);
+    vec3f y_scale_v = make_vec3f(t[0][1], t[1][1], t[2][1]);
+    vec3f z_scale_v = make_vec3f(t[0][2], t[1][2], t[2][2]);
 
     float scale_x = x_scale_v.length();
     float scale_y = y_scale_v.length();
@@ -646,7 +746,7 @@ void bounding_sphere::transform(const mat4f & t)
 
 
 /**
- * @class axis_aligned_bounding_box
+ * @class openvrml::axis_aligned_bounding_box
  *
  * @brief An axis-aligned bounding box.
  *
@@ -656,51 +756,38 @@ void bounding_sphere::transform(const mat4f & t)
 /**
  * @brief Destroy.
  */
-axis_aligned_bounding_box::~axis_aligned_bounding_box()
+openvrml::axis_aligned_bounding_box::~axis_aligned_bounding_box()
+    OPENVRML_NOTHROW
 {}
 
 /**
  * @todo Implement me!
  */
-bounding_volume::intersection
-axis_aligned_bounding_box::intersect_frustum(
-    const openvrml::frustum & frustum) const
+openvrml::bounding_volume::intersection
+openvrml::axis_aligned_bounding_box::
+do_intersect_frustum(const openvrml::frustum &) const
 {
     return bounding_volume::partial;
 }
 
-/**
- * @brief Extend the bounding_volume to enclose @p bv.
- *
- * @param bv    a bounding volume.
- */
-void axis_aligned_bounding_box::extend(const bounding_volume & bv)
-{
-    const bounding_sphere * bs = 0;
-    const axis_aligned_bounding_box * ab = 0;
-    if ((bs = dynamic_cast<const bounding_sphere *>(&bv))) {
-        this->extend(*bs);
-    } else if ((ab = dynamic_cast<const axis_aligned_bounding_box *>(&bv))) {
-        this->extend(*ab);
-    }
-}
-
 /**
  * @todo Implement me!
  */
-void axis_aligned_bounding_box::extend(const vec3f & p)
+void openvrml::axis_aligned_bounding_box::do_extend(const vec3f &)
 {}
 
 /**
  * @todo Implement me!
  */
-void axis_aligned_bounding_box::extend(const axis_aligned_bounding_box & b)
+void
+openvrml::axis_aligned_bounding_box::
+do_extend(const axis_aligned_bounding_box &)
 {}
 
 /**
  * @todo Implement me!
  */
-void axis_aligned_bounding_box::extend(const bounding_sphere& b)
+void openvrml::axis_aligned_bounding_box::do_extend(const bounding_sphere &)
 {}
 
 /**
@@ -708,40 +795,37 @@ void axis_aligned_bounding_box::extend(const bounding_sphere& b)
  *
  * This resets the volume from any previous values.
  *
- * @param points    points.
+ * @param[in] points    points.
  *
  * @todo Implement me!
  */
-void axis_aligned_bounding_box::enclose(const std::vector<vec3f> & points)
+void
+openvrml::axis_aligned_bounding_box::
+do_enclose(const std::vector<vec3f> &)
 {}
 
 /**
  * @brief Implement me!
  */
-void axis_aligned_bounding_box::maximize()
+void openvrml::axis_aligned_bounding_box::do_maximize()
+{}
+
+/**
+ * @brief Implement me!
+ */
+bool openvrml::axis_aligned_bounding_box::do_maximized() const
 {
+    return true;
 }
 
 /**
  * @brief Implement me!
  */
-bool axis_aligned_bounding_box::maximized() const
-{
-  return true;
-}
+void openvrml::axis_aligned_bounding_box::do_ortho_transform(const mat4f &)
+{}
 
 /**
  * @brief Implement me!
  */
-void axis_aligned_bounding_box::ortho_transform(const mat4f & M)
-{
-}
-
-/**
- * @brief Implement me!
- */
-void axis_aligned_bounding_box::transform(const mat4f & M)
-{
-}
-
-} // namespace openvrml
+void openvrml::axis_aligned_bounding_box::do_transform(const mat4f &)
+{}
