@@ -3,7 +3,8 @@
 // OpenVRML
 //
 // Copyright 1998  Chris Morley
-// Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007  Braden McDaniel
+// Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+//   Braden McDaniel
 //
 // This library is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License as published by
@@ -32,7 +33,7 @@
 # include <boost/function.hpp>
 # include <boost/functional.hpp>
 # include <boost/lexical_cast.hpp>
-# include <boost/multi_index/detail/scope_guard.hpp>
+# include <boost/scope_exit.hpp>
 # include <algorithm>
 # include <functional>
 # include <cerrno>
@@ -48,8 +49,6 @@
 #   include <config.h>
 # endif
 
-using namespace boost::multi_index::detail;  // for scope_guard
-
 /**
  * @file openvrml/browser.h
  *
@@ -1873,18 +1872,6 @@ const std::string openvrml::browser::world_url() const
     return this->scene_->url(); // Throws std::bad_alloc.
 }
 
-void openvrml::browser::send_initialized()
-{
-    using boost::shared_lock;
-    using boost::shared_mutex;
-
-    shared_lock<shared_mutex> listeners_lock(this->listeners_mutex_);
-    for_each(this->listeners_.begin(), this->listeners_.end(),
-             boost::bind2nd(
-                 boost::mem_fun(&browser_listener::browser_changed),
-                 browser_event(*this, browser_event::initialized)));
-}
-
 /**
  * @brief Set the world from a stream.
  *
@@ -1903,8 +1890,17 @@ void openvrml::browser::set_world(resource_istream & in)
     //
     // Ensure that the "initialized" event is sent even if parsing throws.
     //
-    scope_guard initialized_event_guard =
-        make_obj_guard(*this, &browser::send_initialized);
+    browser & self = *this;
+    shared_mutex & listeners_mutex = this->listeners_mutex_;
+    std::set<browser_listener *> & listeners = this->listeners_;
+
+    BOOST_SCOPE_EXIT((&self)(&listeners_mutex)(&listeners)) {
+        shared_lock<shared_mutex> listeners_lock(listeners_mutex);
+        for_each(listeners.begin(), listeners.end(),
+                 boost::bind2nd(
+                     boost::mem_fun(&browser_listener::browser_changed),
+                     browser_event(self, browser_event::initialized)));
+    } BOOST_SCOPE_EXIT_END
 
     {
         using std::string;
