@@ -1,36 +1,40 @@
-// -*- Mode: C++; indent-tabs-mode: nil; c-basic-offset: 4; -*-
+// -*- mode: c++; indent-tabs-mode: nil; c-basic-offset: 4; fill-column: 78 -*-
 //
 // OpenVRML
 //
 // Copyright 2000  Christopher K. St. John
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation; either
-// version 2.1 of the License, or (at your option) any later version.
+// This library is free software; you can redistribute it and/or modify it
+// under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or (at your
+// option) any later version.
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Lesser General Public License for more details.
+// This library is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+// License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// You should have received a copy of the GNU Lesser General Public License
+// along with this library; if not, see <http://www.gnu.org/licenses/>.
 //
 
+# include "basetypes.h"
+# include "frustum.h"
+# include <openvrml/local/float.h>
+# include <cmath>
+
 # ifdef HAVE_CONFIG_H
 #   include <config.h>
 # endif
 
-# include "private.h"
-# include "basetypes.h"
-# include "frustum.h"
-
-namespace openvrml {
+/**
+ * @file openvrml/frustum.h
+ *
+ * @brief Definition of @c openvrml::frustum.
+ */
 
 /**
- * @class frustum
+ * @class openvrml::frustum openvrml/frustum.h
  *
  * @brief A view frustum.
  *
@@ -40,36 +44,38 @@ namespace openvrml {
  * the volume of virtual space visible through the on-screen window when using
  * a perspective projection.
  *
- * @see node::render
- * @see viewer
+ * @sa openvrml::appearance_node::render_appearance
+ * @sa openvrml::child_node::render_child
+ * @sa openvrml::geometry_node::render_geometry
+ * @sa openvrml::viewer
  */
 
 /**
- * @var frustum::fovy
+ * @var openvrml::frustum::fovy
  *
  * @brief Vertical field of view.
  */
 
 /**
- * @var frustum::fovx
+ * @var openvrml::frustum::fovx
  *
  * @brief Horizontal field of view.
  */
 
 /**
- * @var frustum::z_near
+ * @var openvrml::frustum::z_near
  *
  * @brief Distance to the near clipping plane.
  */
 
 /**
- * @var frustum::z_far
+ * @var openvrml::frustum::z_far
  *
  * @brief Distance to the far clipping plane.
  */
 
 /**
- * @var frustum::left_plane
+ * @var openvrml::frustum::left_plane
  *
  * @brief Left (looking down -z) side clip plane.
  *
@@ -79,19 +85,19 @@ namespace openvrml {
  */
 
 /**
- * @var frustum::right_plane
+ * @var openvrml::frustum::right_plane
  *
  * @brief Right clipping plane.
  */
 
 /**
- * @var frustum::top_plane
+ * @var openvrml::frustum::top_plane
  *
  * @brief Top clipping plane.
  */
 
 /**
- * @var frustum::bot_plane
+ * @var openvrml::frustum::bot_plane
  *
  * @brief Bottom clipping plane.
  */
@@ -101,7 +107,7 @@ namespace openvrml {
  *
  * fovy, fovx, near and far all get set to -1.
  */
-frustum::frustum():
+openvrml::frustum::frustum():
     fovy(-1),
     fovx(-1),
     z_near(-1),
@@ -116,15 +122,18 @@ frustum::frustum():
  * positive (think distance, not position). anear must be less than afar.
  * This is supposed to look like gluPerspective.
  *
- * @param fovy      vertical field of view in degrees.
- * @param aspect    ratio of view width to height (not the ratio of
+ * @param[in] fovy      vertical field of view in degrees.
+ * @param[in] aspect    ratio of view width to height (not the ratio of
  *                  the horizontal to vertial field-of-views).
- * @param z_near    distance to near clip plane.
- * @param z_far     distance to far clip plane.
+ * @param[in] z_near    distance to near clip plane.
+ * @param[in] z_far     distance to far clip plane.
  *
  */
-frustum::frustum(float fovy, float aspect, double z_near, double z_far):
-    fovy(float((fovy / 360.0) * 2.0 * pi)),
+openvrml::frustum::frustum(float fovy,
+                           float aspect,
+                           double z_near,
+                           double z_far):
+    fovy(float((fovy / 360.0) * 2.0 * openvrml::local::pi)),
     fovx(float(2.0 * atan(float(tan(this->fovy / 2.0)) * aspect))),
     z_near(z_near),
     z_far(z_far)
@@ -133,11 +142,13 @@ frustum::frustum(float fovy, float aspect, double z_near, double z_far):
 }
 
 /**
+ * @internal
+ *
  * @brief Update the plane equations.
  *
  * The plane equations are derived from the other members.
  */
-void frustum::update()
+void openvrml::frustum::update()
 {
     // figure out the corners of the near clipping plane, then use the
     // vectors from the eyepoint to the four corners to figure out the
@@ -212,5 +223,3 @@ void frustum::update()
     bot_plane[2] = top_plane[2];
     bot_plane[3] = 0;
 }
-
-} // namespace openvrml
