@@ -25,14 +25,12 @@
 # include <openvrml/local/parse_vrml.h>
 # include <private.h>
 # include <boost/function.hpp>
-# include <boost/multi_index/detail/scope_guard.hpp>
+# include <boost/scope_exit.hpp>
 
 # ifdef HAVE_CONFIG_H
 #   include <config.h>
 # endif
 
-using namespace boost::multi_index::detail;  // for scope_guard
-
 /**
  * @file openvrml/scene.h
  *
@@ -180,8 +178,10 @@ void openvrml::scene::load(resource_istream & in)
     //
     // Ensure that scene_loaded gets called even if parsing throws.
     //
-    scope_guard scene_loaded_guard =
-        make_obj_guard(*this, &scene::scene_loaded);
+    scene & self = *this;
+    BOOST_SCOPE_EXIT((&self)) {
+        self.scene_loaded();
+    } BOOST_SCOPE_EXIT_END
 
     {
         using boost::unique_lock;
@@ -423,7 +423,9 @@ namespace {
                     const resource_istream::int_type c = this->in_->get();
                     if (c != resource_istream::traits_type::eof()) {
                         data.push_back(
-                            resource_istream::traits_type::to_char_type(c));
+                            static_cast<unsigned char>(
+                                resource_istream::traits_type::
+                                    to_char_type(c)));
                     } else {
                         break;
                     }
