@@ -2,7 +2,7 @@
 //
 // OpenVRML
 //
-// Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007  Braden McDaniel
+// Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2010  Braden McDaniel
 //
 // This library is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License as published by
@@ -23,7 +23,7 @@
 
 # include <openvrml/node_impl_util.h>
 # include <openvrml/viewer.h>
-# include <boost/multi_index/detail/scope_guard.hpp>
+# include <boost/scope_exit.hpp>
 
 namespace openvrml_node_vrml97 {
 
@@ -167,7 +167,6 @@ namespace openvrml_node_vrml97 {
         OPENVRML_THROW1(std::bad_alloc)
     {
         using namespace openvrml;
-        using namespace boost::multi_index::detail;  // for scope_guard
 
         Derived & group = dynamic_cast<Derived &>(this->node());
 
@@ -190,19 +189,21 @@ namespace openvrml_node_vrml97 {
                     // Throws std::bad_alloc.
                     //
                     children.push_back(*n);
-                    scope_guard guard =
-                        make_obj_guard(children, &children_t::pop_back);
+                    bool succeeded = false;
+                    BOOST_SCOPE_EXIT_TPL((&succeeded)(&children)) {
+                        if (!succeeded) { children.pop_back(); }
+                    } BOOST_SCOPE_EXIT_END
                     child_node * const child =
                         node_cast<child_node *>(n->get());
                     if (child) {
                         child->relocate(); // Throws std::bad_alloc.
                     }
-                    guard.dismiss();
+                    succeeded = true;
                 }
             }
         }
 
-        group.children_.mfnode::value(children);
+        group.children_.value(children);
 
         group.node::modified(true);
         group.bounding_volume_dirty(true);
@@ -353,7 +354,6 @@ namespace openvrml_node_vrml97 {
         OPENVRML_THROW1(std::bad_alloc)
     {
         using namespace openvrml;
-        using namespace boost::multi_index::detail;  // for scope_guard
 
         typedef std::vector<boost::intrusive_ptr<openvrml::node> > children_t;
         children_t children;
@@ -367,12 +367,14 @@ namespace openvrml_node_vrml97 {
             // least.
             //
             children.push_back(*n); // Throws std::bad_alloc.
-            scope_guard guard =
-                make_obj_guard(children, &children_t::pop_back);
+            bool succeeded = false;
+            BOOST_SCOPE_EXIT_TPL((&succeeded)(&children)) {
+                if (!succeeded) { children.pop_back(); }
+            } BOOST_SCOPE_EXIT_END
             child_node * const child =
                 node_cast<child_node *>(n->get());
             if (child) { child->relocate(); } // Throws std::bad_alloc.
-            guard.dismiss();
+            succeeded = true;
         }
 
         this->children_.mfnode::value(children);
