@@ -2,7 +2,7 @@
 //
 // OpenVRML
 //
-// Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007  Braden McDaniel
+// Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2010  Braden McDaniel
 //
 // This library is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,7 @@
 
 # include <sstream>
 # include <boost/algorithm/string/predicate.hpp>
-# include <boost/multi_index/detail/scope_guard.hpp>
+# include <boost/scope_exit.hpp>
 # include "image_stream_listener.h"
 
 openvrml_node_vrml97::image_stream_listener::image_reader::~image_reader()
@@ -136,7 +136,9 @@ void openvrml_png_info_callback(png_structp png_ptr, png_infop info_ptr)
 
     png_read_update_info(png_ptr, info_ptr);
 
-    reader.old_row.resize(png_ptr->rowbytes);
+    reader.width = png_get_image_width(png_ptr, info_ptr);
+    reader.rowbytes = png_get_rowbytes(png_ptr, info_ptr);
+    reader.old_row.resize(reader.rowbytes);
 }
 
 void openvrml_png_row_callback(png_structp png_ptr,
@@ -166,9 +168,7 @@ void openvrml_png_row_callback(png_structp png_ptr,
     // openvrml::image pixels start at the bottom left.
     //
     const size_t image_row = (image.y() - 1) - row_num;
-    const size_t bytes_per_row = png_ptr->rowbytes;
-    const size_t image_width = png_ptr->width;
-    for (size_t pixel_index = 0, byte_index = 0; pixel_index < image_width;
+    for (size_t pixel_index = 0, byte_index = 0; pixel_index < reader.width;
          ++pixel_index) {
         using openvrml::int32;
         int32 pixel = 0x00000000;
@@ -188,14 +188,14 @@ void openvrml_png_row_callback(png_structp png_ptr,
                 ++byte_index;
             }
         }
-        image.pixel(image_row * image_width + pixel_index, pixel);
+        image.pixel(image_row * reader.width + pixel_index, pixel);
     }
 
     reader.stream_listener.node_.modified(true);
 
-    assert(reader.old_row.size() >= bytes_per_row);
+    assert(reader.old_row.size() >= reader.rowbytes);
 
-    copy(new_row, new_row + bytes_per_row, reader.old_row.begin());
+    copy(new_row, new_row + reader.rowbytes, reader.old_row.begin());
 }
 
 void openvrml_png_end_callback(png_structp, png_infop)
@@ -208,14 +208,15 @@ png_reader(image_stream_listener & stream_listener):
     stream_listener(stream_listener),
     gray_palette(false)
 {
-    using namespace boost::multi_index::detail;  // for scope_guard
     this->png_ptr_ =
         png_create_read_struct(PNG_LIBPNG_VER_STRING, 0, 0, 0);
     if (!this->png_ptr_) { throw std::bad_alloc(); }
-    scope_guard guard = make_guard(&png_destroy_read_struct,
-                                   &this->png_ptr_,
-                                   &this->info_ptr_,
-                                   png_infopp(0));
+    bool succeeded = false;
+    BOOST_SCOPE_EXIT((&succeeded)(&png_ptr_)(&info_ptr_)) {
+        if (!succeeded) {
+            png_destroy_read_struct(&png_ptr_, &info_ptr_, png_infopp(0));
+        }
+    } BOOST_SCOPE_EXIT_END
 
     this->info_ptr_ = png_create_info_struct(this->png_ptr_);
     if (!this->info_ptr_) { throw std::bad_alloc(); }
@@ -225,7 +226,7 @@ png_reader(image_stream_listener & stream_listener):
                                 openvrml_png_info_callback,
                                 openvrml_png_row_callback,
                                 openvrml_png_end_callback);
-    guard.dismiss();
+    succeeded = true;
 }
 
 openvrml_node_vrml97::image_stream_listener::png_reader::~png_reader()
